@@ -10,9 +10,60 @@ import collections.abc
 import numpy as np
 import tqdm
 from collections import defaultdict
+from ._version import *
 
 
-__version__ = '0.14.2'
+def CheckAllIsFile(paths):
+    r'''
+Check that all paths point to existing files.
+Uses: ``os.path.isfile``.
+
+:param list paths: List of file paths.
+:throw: IOError
+    '''
+
+    for path in paths:
+        if not os.path.isfile(path):
+            raise IOError('"{0:s}" does not exist'.format(path))
+
+
+def DirNames(paths, return_unique=True):
+    r'''
+Get the ``os.path.dirname`` of all file paths.
+
+:param list paths: List of file paths.
+:param bool return_unique: Filter duplicates.
+:return: List of dirnames.
+    '''
+
+    ret = [os.path.dirname(path) for path in paths]
+
+    if not return_unique:
+        return ret
+
+    return list(set(ret))
+
+
+def OverWrite(paths, force=False):
+    r'''
+List files that will be overwritten.
+
+:param list paths: List of file paths.
+:param bool force: If ``True`` the user is prompted to overwrite.
+:return: List of overwritten files.
+    '''
+
+    ret = [path for path in paths if os.path.isfile(path)]
+
+    if not force:
+        return ret
+
+    print('Files exist:')
+    print('\n'.join(ret))
+    if not click.confirm('Overwrite?'):
+        raise IOError('Cancelled')
+
+    return ret
 
 
 def _FlattenList_detail(data):
@@ -161,6 +212,10 @@ def PrefixPaths(prefix, files):
     r'''
 Add prefix to a list of filenames.
 Skip if all paths are absolute paths.
+
+:param str prefix: The prefix.
+:param list files: List of paths.
+:return: List of paths.
     '''
 
     isabs = [os.path.isabs(file) for file in files]
@@ -282,9 +337,9 @@ Copy files to a remote system using ``rsync -a --files-from``.
 
     process = subprocess.Popen(cmd, stdout=subprocess.PIPE, shell=True)
 
-    for line in iter(process.stdout.readline, ''):
+    for line in iter(process.stdout.readline, b''):
         line = line.decode("utf-8")
-        if re.match(r'(.*)(xfr\#)([0-9])(.*)(to\-chk\=)([0-9])(.*)', line):
+        if re.match(r'(.*)(xf)([e]?)(r\#)([0-9])(.*)(to\-ch)([e]?[c]?)(k\=)([0-9])(.*)', line):
             e = int(list(filter(None, line.split(" ")))[-6].replace(",", ""))
             pbar.update()
             sbar.update(e)
@@ -410,7 +465,8 @@ Same as :py:mod:`shelephant.MakeDir` but for list of directories.
     if len(dirnames) == 0:
         return 0
 
-    dirnames = GetDeepestPaths(dirnames)
+    dirnames = list(set(dirnames))
+    dirnames = sorted(GetDeepestPaths(dirnames))
 
     if not force:
         for dirname in dirnames:
@@ -441,24 +497,19 @@ def GetChecksums(filepaths, yaml_hostinfo=None, hybrid=False, progress=False):
     r'''
 Compute the checksums for ``filepaths``.
 
-:type filepaths: list of str
-:param filepaths: List of file-paths.
+:param list filepaths: List of file-paths.
 
-:type yaml_hostinfo: str
-:param yaml_hostinfo:
+:param set yaml_hostinfo:
     File-path of a host-info file (see :py:mod:`shelephant.cli.hostinfo`).
     If specified the checksums are **not** computed, but exclusively read from the
     host-file. The user is responsible for keeping them up-to-date.
 
-:type hybrid: bool
-:param hybrid:
+:param bool hybrid:
     If ``True``, the function first tries to read from ``yaml_hostinfo``, and then
     computes missing items on the fly.
 
-:type progress: ([``False``] | ``True``)
-:param progress: Show a progress-bar.
+:param bool progress: Show a progress-bar.
 
-:rtype: list of str
 :return:
     List of checksums, of same length as ``filepaths``.
     The entry is ``None`` if no checksum was found/read.
@@ -548,7 +599,7 @@ Copy/move files.
 :param bool print_all: If ``False`` auto-truncation of long output is applied.
 
 :type theme_name: str or None
-:param theme_name: The name of the color-theme. See ``Theme``.
+:param theme_name: The name of the color-theme. See :py:mod:`shelephant.Theme`.
 
 :type yaml_hostinfo_src: str, optional
 :param yaml_hostinfo_src:
@@ -580,7 +631,7 @@ Copy/move files.
         if not os.path.isfile(file):
             raise IOError('Input file "{0:s}" does not exists'.format(file))
 
-    if not os.path.isdir(dest_dir):
+    if not os.path.isdir(dest_dir) and len(dest_dir) > 0:
 
         create = [True for i in range(n)]
 
@@ -695,7 +746,7 @@ Get/send files.
 
 :param function copy_function: Function to perform the copy. E.g. ``CopyFromRemote``.
 
-:param std host: Host-name
+:param str host: Host-name
 
 :type files: list of str
 :param files: Filenames (will be prepended by ``src_dir`` and ``dest_dir``).
@@ -739,6 +790,18 @@ Get/send files.
             print('Nothing to do')
         return
 
+    if copy_function in [CopyToRemote, RsyncToRemote]:
+        to_remote = True
+    elif copy_function in [CopyFromRemote, RsyncFromRemote]:
+        to_remote = False
+    else:
+        raise IOError('Unknown copy function')
+
+    if copy_function in [RsyncToRemote, RsyncFromRemote]:
+        use_rsync = True
+    else:
+        use_rsync = False
+
     src = PrefixPaths(src_dir, files)
     dest = PrefixPaths(dest_dir, files)
     n = len(src)
@@ -746,32 +809,38 @@ Get/send files.
     create = [False for i in range(n)]
     skip = [False for i in range(n)]
     dest_exists = [False for i in range(n)]
-    theme = Theme(theme_name)
+    theme = Theme(theme_name.lower())
 
-    if checksum == True:
-        src_checksums = GetChecksums(src, yaml_hostinfo_src, progress=not quiet)
-        dest_checksums = GetChecksums(dest, yaml_hostinfo_dest, progress=not quiet)
+    if not os.path.isdir(dest_dir) and len(dest_dir) > 0:
+
+        create = [True for i in range(n)]
 
-    if copy_function == CopyToRemote:
-        if yaml_hostinfo_dest:
-            f = YamlRead(yaml_hostinfo_dest)['files']
-            for i in range(n):
-                if files[i] in f:
-                    dest_exists[i] = True
     else:
-        for i in range(n):
-            if os.path.isfile(dest[i]):
-                dest_exists[i] = True
 
-    for i in range(n):
-        if dest_exists[i]:
-            if checksum:
-                if (src_checksums[i] == dest_checksums[i]) and (src_checksums[i] is not None):
-                    skip[i] = True
-                    continue
-            overwrite[i] = True
-            continue
-        create[i] = True
+        if checksum == True:
+            src_checksums = GetChecksums(src, yaml_hostinfo_src, progress=not quiet)
+            dest_checksums = GetChecksums(dest, yaml_hostinfo_dest, progress=not quiet)
+
+        if to_remote:
+            if yaml_hostinfo_dest:
+                f = YamlRead(yaml_hostinfo_dest)['files']
+                for i in range(n):
+                    if files[i] in f:
+                        dest_exists[i] = True
+        elif not to_remote:
+            for i in range(n):
+                if os.path.isfile(dest[i]):
+                    dest_exists[i] = True
+
+        for i in range(n):
+            if dest_exists[i]:
+                if checksum:
+                    if (src_checksums[i] == dest_checksums[i]) and (src_checksums[i] is not None):
+                        skip[i] = True
+                        continue
+                overwrite[i] = True
+                continue
+            create[i] = True
 
     l = max([len(file) for file in files])
     ncreate = sum(create)
@@ -791,7 +860,7 @@ Get/send files.
         overview += [String('skip (==): {0:d}{1:s}'.format(nskip, pskip_message), color=theme['skip']).format()]
 
     summary = []
-    if copy_function == CopyToRemote:
+    if to_remote:
         summary += ['- to host        : ' + host]
         summary += ['- source (local) : ' + os.path.normpath(src_dir)]
         summary += ['- dest (remote)  : ' + os.path.normpath(dest_dir)]
@@ -839,12 +908,15 @@ Get/send files.
         if not click.confirm('Proceed?'):
             raise IOError('Cancelled')
 
+    if not to_remote:
+        MakeDirs(list(set([os.path.dirname(i) for i in dest])))
+
     i = np.argwhere(np.not_equal(skip, True)).ravel()
     src = np.array(src)[i]
     dest = np.array(dest)[i]
     files = np.array(files)[i]
 
-    if copy_function == RsyncToRemote or copy_function == RsyncFromRemote:
+    if use_rsync:
         dest_dir = dest_dir if len(dest_dir) > 0 else '.'
         src_dir = src_dir if len(src_dir) > 0 else '.'
         return copy_function(host, src_dir, dest_dir, tempfilename, files, force, verbose, not quiet)
